api library

Classes

Action
ActionRow
Activity
ActivityEmoji
AnnouncementChannelBuilder
AppEnv
ApplicationCommandPermission
A single permission entry for a guild application command.
ApplicationEmojiManager
AttachedFile
AutocompleteContext
Context passed to an autocomplete handler when Discord sends an INTERACTION_CREATE event with type=4 (APPLICATION_COMMAND_AUTOCOMPLETE).
AutoModerationRule
BaseMessage
BaseMessageReaction
Bot
BotActivity
Button
ButtonContext
CategoryChannelBuilder
Channel
ChannelBuilder
ChannelBuilderContract
ChannelCreateAuditLogAction
ChannelDeleteAuditLogAction
ChannelManager<C extends Channel>
ChannelMethods
ChannelPermissionOverwrite
ChannelProperties
ChannelUpdateAuditLogAction
Choice<T>
ChoiceOption
Client
ClientBuilder
Color
CommandBuilder
CommandContext
CommandContract<T extends CommandBuilder>
CommandDeclaration
CommandDeclarationBuilder
CommandDefinition
CommandDefinitionBuilder
CommandFailure
CommandGroupBuilder
CommandHelper
CommandOption
CommandOptions
CommandRegistration
CommandResult
CommandSuccess
Component
ComponentContext
ComponentContextBase
DefineEnvironment
Emoji
EmojiCreateAuditLog
EmojiDeleteAuditLog
EmojiManager
EmojiUpdateAuditLog
EnhancedEnum<R>
Entitlement
Enumerable<T>
Env
EnvSchema<T extends ErrorReporter>
ForumChannelBuilder
GlobalCommandContext
GlobalState<T>
Guild
GuildAnnouncementChannel
GuildApplicationCommandPermissions
The full permissions object for a guild application command as sent by the APPLICATION_COMMAND_PERMISSIONS_UPDATE gateway event.
GuildAsset
GuildButtonContext
GuildCategoryChannel
GuildChannel
GuildCommandContext
GuildForumChannel
GuildMessage
GuildMessageReaction
GuildModalContext
GuildScheduledEvent
GuildScheduledEventEntityMetadata
GuildScheduledEventUser
GuildSelectContext
GuildSettings
GuildStageChannel
GuildSubscription
GuildTemplate
A guild template that can be used to create a new guild.
GuildTextChannel
GuildUpdateAuditLogAction
GuildVoiceChannel
Image
ImageAsset
Integration
A Discord guild integration (Twitch, YouTube, Discord, guild_subscription…).
IntegrationAccount
Minimal account info bundled with every Integration.
IntegrationApplication
Minimal application info optionally bundled with an Integration.
Intent
Gateway intents for controlling which events your bot receives from Discord.
Invite
InviteMetadata
MediaGallery
MediaItem
Member
MemberAssets
MemberBuilder
MemberFlagsManager
MemberManager
MemberRecord
MemberRoleManager
MemberTimeout
MemberVoice
Message
MessageBuilder
A builder for constructing Discord messages using message components v2.
MessageCommand
MessageCommandBuilder
MessageCommandContext
MessageComponent
MessageEmbed
MessageEmbedAssets
MessageEmbedAuthor
MessageEmbedBuilder
MessageEmbedField
MessageEmbedFooter
MessageEmbedImage
MessageEmbedProvider
MessageProperties<T extends Channel>
MessageReaction
MessageSnapshot
A minimal snapshot of a forwarded message, as provided by Discord in the message_snapshots array on a forwarded message payload.
ModalBuilder
A builder for constructing Discord modal dialogs (popup forms).
ModalComponent
ModalContext
MonetizationManager
Onboarding
A guild's onboarding configuration.
OnboardingPrompt
A single onboarding prompt shown to new members.
OnboardingPromptOption
An option inside an OnboardingPrompt.
Option
PartialApplication
PartialEmoji
Poll
PollAnswer
PollBuilder
PollQuestion
Presence
PrivateButtonContext
PrivateChannel
PrivateGroupChannel
PrivateMessage
PrivateMessageReaction
PrivateModalContext
PrivateSelectContext
Provider
ProviderContract
Role
RoleCreateAuditLog
RoleDeleteAuditLog
RoleManager
RoleUpdateAuditLog
RuleExecution
ScheduledEventManager
Section
SelectContext
SelectMenu<T>
SelectMenuOption<T>
Separator
Sku
SoundboardManager
SoundboardSound
Represents a Discord soundboard sound (either a default sound or a guild-specific custom sound).
StageInstance
Represents a live stage instance associated with a stage channel.
Sticker
StickerManager
SubCommandBuilder
SubCommandDeclaration
Subscription
TemplateManager
TextChannelBuilder
TextInput
ThreadChannel
ThreadChannelBuilder
ThreadResult
Thumbnail
Timestamp
Translation
Typing
Represents a typing indicator in a channel.
UnknownChannel
User
UserAssets
UserCommand
UserCommandBuilder
UserCommandContext
VoiceChannelBuilder
VoiceState
Webhook
WelcomeChannel
A single channel shown on a guild's welcome screen.
WelcomeScreen
A guild's welcome screen shown to new members.

Extension Types

Snowflake

Extensions

YamlMapConverter on YamlMap

Properties

env → Env
final

Typedefs

AutocompleteHandler = FutureOr<List<Choice>> Function(AutocompleteContext ctx)
Handler signature for autocomplete options.
CommandHandler<T extends CommandContext> = FutureOr<void> Function(T context, CommandOptions options)

Exceptions / Errors

CommandNameException
FatalGatewayException
FatalMineralException
An exception that indicates the bot cannot continue running.
HttpStatusException
InvalidCommandException
InvalidComponentException
MineralException
Root of the Mineral exception hierarchy.
MissingMethodException
MissingPropertyException
RecoverableMineralException
An exception the bot can catch, log, and potentially recover from.
SerializationException
ServiceNotFoundException
TokenException
TooManyElementException