BotActivity class

Constructors

BotActivity({required GamePresence type, String? name, String? url, PartialEmoji? emoji, String? state})
BotActivity.listening(String name)
factory
BotActivity.playing(String name)
factory
BotActivity.streaming(String name, String url)
factory
BotActivity.watching(String name)
factory

Properties

emoji ↔ PartialEmoji?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
getter/setter pair
type ↔ GamePresence
getter/setter pair
url ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited