ButtonContext class abstract interface

Implemented types
Implementers

Properties

applicationId → Snowflake
no setterinherited
customId → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → Snowflake
no setterinherited
interaction → InteractionContract
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → String
no setterinherited
version → int
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited