ChannelManager<C extends Channel> class
final
Constructors
- ChannelManager(Snowflake _guildId, {required EntityContext ctx, required Snowflake? afkChannelId, required Snowflake? systemChannelId, required Snowflake? rulesChannelId, required Snowflake? publicUpdatesChannelId, required Snowflake? safetyAlertsChannelId})
- ChannelManager.empty(String guildId, {required EntityContext ctx})
-
factory
-
ChannelManager.fromMap(Object guildId, Map<
String, dynamic> payload, {required EntityContext ctx}) -
factory
Properties
- afkChannelId → Snowflake?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- publicUpdatesChannelId → Snowflake?
-
final
- rulesChannelId → Snowflake?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- safetyAlertsChannelId → Snowflake?
-
final
- systemChannelId → Snowflake?
-
final
Methods
-
create<
T extends C> (ChannelBuilderContract builder, {String? reason}) → Future< T> - Create a channel.
-
fetch(
{bool force = false}) → Future< Map< Snowflake, C> > - Fetch the guild's channels.
-
get<
T extends C> (String id, {bool force = false}) → Future< T?> - Get a channel by its id.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolveAfkChannel(
{bool force = false}) → Future< GuildVoiceChannel?> - Resolve the guild's afk channel.
-
resolvePublicUpdatesChannel(
{bool force = false}) → Future< GuildTextChannel?> - Resolve the guild's public updates channel.
-
resolveRulesChannel(
{bool force = false}) → Future< GuildTextChannel?> - Resolve the guild's rules channel.
-
resolveSafetyAlertsChannel(
{bool force = false}) → Future< GuildTextChannel?> - Resolve the guild's safety alerts channel.
-
resolveSystemChannel(
{bool force = false}) → Future< GuildTextChannel?> - Resolve the guild's system channel.
-
setAfkChannel(
String? channelId, {String? reason}) → Future< void> - Set the guild's afk channel.
-
setPublicUpdatesChannel(
String? channelId, {String? reason}) → Future< void> - Set the guild's public updates channel.
-
setRulesChannel(
String? channelId, {String? reason}) → Future< void> - Set the guild's rules channel.
-
setSystemChannel(
String? channelId, {String? reason}) → Future< void> - Set the guild's system channel.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited