CommandContext class abstract

Implementers

Constructors

CommandContext({required Snowflake id, required Snowflake applicationId, required String token, required int version, required EntityContext ctx, Channel? channel})

Properties

applicationId Snowflake
final
channel Channel?
The channel in which the command was invoked, if available.
final
ctx → EntityContext
Entity context required to construct Interaction; subclasses pass their own EntityContext through super.ctx.
final
hashCode int
The hash code for this object.
no setterinherited
id Snowflake
final
interaction InteractionContract
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
final
version int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited