declaration property

The declarative option tree backing this command, used to discover autocomplete handlers.

null for builders with no option tree to walk (user and message commands).

Implementation

@override
CommandDeclarationBuilder? get declaration => command;