GuildAsset class final

Constructors

GuildAsset(Snowflake guildId, {required EntityContext ctx, required EmojiManager emojis, required StickerManager stickers, required ImageAsset? icon, required ImageAsset? splash, required ImageAsset? banner, required ImageAsset? discoverySplash})

Properties

final
discoverySplash ImageAsset?
final
emojis EmojiManager
final
guildId Snowflake
final
hashCode int
The hash code for this object.
no setterinherited
icon ImageAsset?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
splash ImageAsset?
final
stickers StickerManager
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBanner(File banner, {String? reason}) Future<void>
Set the guild's banner.
setDiscoverySplash(File discoverySplash, {String? reason}) Future<void>
Set the guild's discovery splash.
setIcon(File icon, {String? reason}) Future<void>
Set the guild's icon.
setSplash(File splash, {String? reason}) Future<void>
Set the guild's splash.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited