GuildSelectContext class final

Inheritance
Implemented types

Constructors

GuildSelectContext({required Snowflake id, required Snowflake applicationId, required String token, required int version, required String customId, required Snowflake guildId, required Snowflake? messageId, required Snowflake? memberId, required Snowflake? channelId, required EntityContext ctx})

Properties

applicationId → Snowflake
finalinherited
channelId → Snowflake?
finalinherited
ctx → EntityContext
Entity context required to construct Interaction; subclasses (button/select/modal contexts) pass their own EntityContext.ctx through super.ctx.
finalinherited
customId → String
finalinherited
guildId → Snowflake
final
hashCode → int
The hash code for this object.
no setterinherited
id → Snowflake
finalinherited
interaction → InteractionContract
latefinalinherited
memberId → Snowflake?
final
messageId → Snowflake?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → String
finalinherited
version → int
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveChannel<T extends Channel>({bool force = false}) → Future<T?>
resolveMember({bool force = false}) → Future<Member?>
resolveMessage({bool force = false}) → Future<GuildMessage?>
Resolves the message that triggered this select interaction, if available.
resolveServer({bool force = false}) → Future<Guild?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(DataStoreContract datastore, EntityContext ctx, Map<String, dynamic> payload) → Future<GuildSelectContext>