MessageCommandContext class final

Inheritance

Constructors

MessageCommandContext({required Snowflake id, required Snowflake applicationId, required String token, required int version, required EntityContext ctx, required Message target, Guild? guild, Channel? channel})

Properties

applicationId → Snowflake
finalinherited
channel → Channel?
The channel in which the command was invoked, if available.
finalinherited
ctx → EntityContext
Entity context required to construct Interaction; subclasses pass their own EntityContext through super.ctx.
finalinherited
guild → Guild?
final
hashCode → int
The hash code for this object.
no setterinherited
id → Snowflake
finalinherited
interaction → InteractionContract
latefinalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target → Message
final
token → String
finalinherited
version → int
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(MarshallerContract marshaller, DataStoreContract datastore, EntityContext ctx, Map<String, dynamic> payload) → Future<MessageCommandContext>