MessageEmbedAssets class final

Constructors

MessageEmbedAssets({required MessageEmbedImage? image, required MessageEmbedImage? thumbnail, required MessageEmbedImage? video, required MessageEmbedFooter? footer, required MessageEmbedAuthor? author})
const
MessageEmbedAssets.fromJson(Map<String, dynamic> json)
factory

Properties

author → MessageEmbedAuthor?
final
final
hashCode → int
The hash code for this object.
no setterinherited
image → MessageEmbedImage?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnail → MessageEmbedImage?
final
video → MessageEmbedImage?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited