PrivateSelectContext class final

Inheritance
Implemented types

Constructors

PrivateSelectContext({required Snowflake id, required Snowflake applicationId, required String token, required int version, required String customId, required Snowflake? messageId, required Snowflake userId, required Snowflake? channelId, required EntityContext ctx})

Properties

applicationId Snowflake
finalinherited
channelId Snowflake?
finalinherited
ctx → EntityContext
Entity context required to construct Interaction; subclasses (button/select/modal contexts) pass their own EntityContext.ctx through super.ctx.
finalinherited
customId String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
id Snowflake
finalinherited
interaction InteractionContract
latefinalinherited
messageId Snowflake?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
finalinherited
userId Snowflake
final
version int
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveChannel({bool force = false}) FutureOr<PrivateChannel?>
resolveMessage({bool force = false}) FutureOr<PrivateMessage?>
Resolves the message that triggered this select interaction, if available.
resolveUser({bool force = false}) Future<User?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromMap(MarshallerContract marshaller, DataStoreContract datastore, EntityContext ctx, Map<String, dynamic> payload) Future<PrivateSelectContext>