ResponseCode enum

Inheritance
Available extensions

Values

success → const ResponseCode
const ResponseCode(200, 'The request is passed with success')
created → const ResponseCode
const ResponseCode(201, 'The request is created with success')
accepted → const ResponseCode
const ResponseCode(202, 'The request is accepted')
noContent → const ResponseCode
const ResponseCode(204, 'The request is passed with success but no content')
badRequest → const ResponseCode
const ResponseCode(400, 'The request is invalid')
unauthorized → const ResponseCode
const ResponseCode(401, 'The request is unauthorized')
forbidden → const ResponseCode
const ResponseCode(403, 'The request is forbidden')
notFound → const ResponseCode
const ResponseCode(404, 'The request is not found')
methodNotAllowed → const ResponseCode
const ResponseCode(405, 'The request method is not allowed')
rateLimit → const ResponseCode
const ResponseCode(429, 'The request is rate limited')
internalServerError → const ResponseCode
const ResponseCode(500, 'An internal server error occurred')
notImplemented → const ResponseCode
const ResponseCode(501, 'The request is not implemented')
badGateway → const ResponseCode
const ResponseCode(502, 'The request is invalid')
serviceUnavailable → const ResponseCode
const ResponseCode(503, 'The service is unavailable')
gatewayTimeout → const ResponseCode
const ResponseCode(504, 'The gateway is timeout')
unknown → const ResponseCode
const ResponseCode(0, 'An unknown error occurred')

Properties

code → int
final
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
message → String
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

errorsCodes → List<ResponseCode>
no setter
rateLimitCodes → List<ResponseCode>
no setter
successCodes → List<ResponseCode>
no setter

Constants

values → const List<ResponseCode>
A constant List of the values in this enum, in order of their declaration.