ServerButtonContext class final

Inheritance
Implemented types

Constructors

ServerButtonContext({required Snowflake id, required Snowflake applicationId, required String token, required int version, required String customId, required Snowflake channelId, required Snowflake messageId, required EntityContext ctx})

Properties

applicationId Snowflake
finalinherited
channelId Snowflake
finalinherited
ctx → EntityContext
Entity context required to construct Interaction; subclasses (button/select/modal contexts) pass their own EntityContext.ctx through super.ctx.
finalinherited
customId String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
id Snowflake
finalinherited
interaction InteractionContract
latefinalinherited
messageId Snowflake
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
finalinherited
version int
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveChannel({bool force = false}) Future<ServerChannel>
inherited
resolveMessage({bool force = false}) Future<ServerMessage>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited