ServerChannel class abstract

Implemented types
Implementers

Constructors

ServerChannel()

Properties

categoryId Snowflake?
no setter
createdAt DateTime
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
id Snowflake
no setteroverride
methods ChannelMethods
no setter
name String
no setter
permissions List<ChannelPermissionOverwrite>
no setter
position int
no setter
properties ChannelProperties
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverId Snowflake
no setter
type ChannelType
no setteroverride

Methods

cast<T extends Channel>() → T
override
delete({String? reason}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveServer({bool force = true}) Future<Server>
Resolves the Server the channel belongs to.
setName(String name, {String? reason}) Future<void>
setPosition(int position, {String? reason}) Future<void>
toString() String
A string representation of this object.
inherited
update(ChannelBuilderContract builder, {String? reason}) Future<void>
Updates the channel.

Operators

operator ==(Object other) bool
The equality operator.
inherited