ServerStageChannel class final

Inheritance

Constructors

ServerStageChannel(ChannelProperties properties)

Properties

category ServerCategoryChannel?
latefinal
categoryId Snowflake?
no setterinherited
createdAt DateTime
no setterinherited
description String?
no setter
hashCode int
The hash code for this object.
no setterinherited
id Snowflake
no setterinherited
messages ↔ MessageManager<ServerMessage>
latefinal
methods ChannelMethods
latefinaloverride-getter
name String
no setterinherited
permissions List<ChannelPermissionOverwrite>
no setterinherited
position int
no setterinherited
properties ChannelProperties
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverId Snowflake
no setterinherited
threads → ThreadsManager
no setter
type ChannelType
no setterinherited

Methods

cast<T extends Channel>() → T
inherited
delete({String? reason}) Future<void>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveServer({bool force = true}) Future<Server>
Resolves the Server the channel belongs to.
inherited
setCategory(String categoryId, {String? reason}) Future<void>
setDefaultAutoArchiveDuration(Duration value, {String? reason}) Future<void>
setDefaultThreadRateLimitPerUser(Duration value, {String? reason}) Future<void>
setDescription(String description, {String? reason}) Future<void>
setName(String name, {String? reason}) Future<void>
inherited
setNsfw(bool nsfw, {String? reason}) Future<void>
setPosition(int position, {String? reason}) Future<void>
inherited
setRateLimitPerUser(Duration value, {String? reason}) Future<void>
toString() String
A string representation of this object.
inherited
update(ChannelBuilderContract builder, {String? reason}) Future<void>
Updates the channel.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited