SubCommandBuilder class final

Constructors

SubCommandBuilder()

Properties

handle ↔ Function?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
getter/setter pair
options → List<CommandOption>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addOption<T extends CommandOption>(T option) → SubCommandBuilder
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setDescription(String description, {Translation? translation}) → SubCommandBuilder
setHandle<T extends CommandContext>(CommandHandler<T> fn) → SubCommandBuilder
setName(String name, {Translation? translation}) → SubCommandBuilder
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited