User class final

Constructors

User({required EntityContext ctx, required Snowflake id, required String username, required String discriminator, required String? avatar, required bool? bot, required bool? system, required bool? mfaEnabled, required String? locale, required bool? verified, required String? email, required int? flags, required PremiumTier? premiumType, required int? publicFlags, required UserAssets assets, required DateTime? createdAt, required Presence? presence})

Properties

assets → UserAssets
final
avatar → String?
final
bot → bool?
final
createdAt → DateTime?
final
discriminator → String
final
email → String?
final
flags → int?
final
hashCode → int
The hash code for this object.
no setterinherited
id → Snowflake
final
locale → String?
final
mfaEnabled → bool?
final
premiumType → PremiumTier?
final
presence ↔ Presence?
getter/setter pair
publicFlags → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
system → bool?
final
username → String
final
verified → bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMember(String guildId) → Future<Member?>
Resolve the user as Member from Guild id.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited