WelcomeScreen class final

A guild's welcome screen shown to new members.

Constructors

WelcomeScreen({required String? description, required List<WelcomeChannel> welcomeChannels})
const
WelcomeScreen.fromJson(Map<String, dynamic> json)
factory

Properties

description String?
The guild description shown in the welcome screen.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
welcomeChannels List<WelcomeChannel>
The channels shown in the welcome screen (up to 5).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited