ApplicationEmojiPartContract class abstract interface

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(Object applicationId, String name, Image image) Future<Emoji>
delete(Object applicationId, Object emojiId) Future<void>
fetch(Object applicationId) Future<Map<Snowflake, Emoji>>
get(Object applicationId, Object emojiId) Future<Emoji?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(Object applicationId, Object emojiId, String name) Future<Emoji?>

Operators

operator ==(Object other) bool
The equality operator.
inherited