ChannelPartContract class abstract interface

Implemented types

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

create<T extends Channel>(Object? guildId, ChannelBuilderContract builder, {String? reason}) → Future<T>
createPrivateChannel(Object id, String recipientId) → Future<PrivateChannel?>
delete(Object id, String? reason) → Future<void>
fetch<T extends Channel>(Object guildId, bool force) → Future<Map<Snowflake, T>>
get<T extends Channel>(Object id, bool force) → Future<T?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
update<T extends Channel>(Object id, ChannelBuilderContract builder, {Object? guildId, String? reason}) → Future<T?>

Operators

operator ==(Object other) → bool
The equality operator.
inherited