DataStoreContract class abstract

Constructors

DataStoreContract()

Properties

applicationEmoji → ApplicationEmojiPartContract
no setter
channel → ChannelPartContract
no setter
client → HttpClientContract
no setter
emoji → EmojiPartContract
no setter
guild → GuildPartContract
no setter
hashCode → int
The hash code for this object.
no setterinherited
interaction → InteractionPartContract
no setter
invite → InvitePartContract
no setter
member → MemberPartContract
no setter
message → MessagePartContract
no setter
monetization → MonetizationPartContract
no setter
onboarding → OnboardingPartContract
no setter
reaction → ReactionPartContract
no setter
requestBucket → RequestBucketContract
no setter
role → RolePartContract
no setter
rules → RulesPartContract
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheduledEvent → GuildScheduledEventPartContract
no setter
soundboard → SoundboardPartContract
no setter
stageInstance → StageInstancePartContract
no setter
sticker → StickerPartContract
no setter
template → TemplatePartContract
no setter
thread → ThreadPartContract
no setter
user → UserPartContract
no setter
webhook → WebhookPartContract
no setter
welcomeScreen → WelcomeScreenPartContract
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited