InteractionPartContract class abstract interface

Implemented types

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createFollowup(Snowflake botId, String token, MessageBuilder builder, bool ephemeral) → Future<void>
deleteFollowup(Snowflake botId, String token, Snowflake messageId) → Future<void>
deleteInteraction(Snowflake botId, String token) → Future<void>
editFollowup(Snowflake botId, String token, Snowflake messageId, MessageBuilder builder, bool ephemeral) → Future<void>
editInteraction(Snowflake botId, String token, MessageBuilder builder, bool ephemeral) → Future<void>
noReplyInteraction(Snowflake id, String token, bool ephemeral) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replyInteraction(Snowflake id, String token, MessageBuilder builder, bool ephemeral) → Future<void>
sendAutocompleteResult(Snowflake id, String token, List<Choice> choices) → Future<void>
sendModal(Snowflake id, String token, ModalBuilder modal) → Future<void>
toString() → String
A string representation of this object.
inherited
waitInteraction(Snowflake id, String token) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited