InteractiveComponentManagerContract class abstract interface

Implemented types
Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
onComponentError ↔ void Function(InteractiveComponent component, Object error, StackTrace stackTrace)?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispatch(String customId, List params) Future<void>
get<T extends InteractiveComponent>(String customId) → T
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(InteractiveComponent component) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited