InvitePartContract class abstract interface

Implemented types

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

create({required Object channelId, Duration? maxAge, int? maxUses, bool? temporary, bool? unique, InviteTargetType? targetType, Object? targetUserId, Object? targetApplicationId, String? reason}) → Future<Invite>
delete(String code, String? reason) → Future<void>
get(String code, bool force) → Future<Invite?>
getExtrasMetadata(String code, bool force) → Future<InviteMetadata?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited