LogLevel enum
- Inheritance
- Implemented types
- Available extensions
Values
- trace → const LogLevel
-
const LogLevel('TRACE', Level.FINEST) - fatal → const LogLevel
-
const LogLevel('FATAL', Level.SHOUT) - error → const LogLevel
-
const LogLevel('ERROR', Level.SEVERE) - warn → const LogLevel
-
const LogLevel('WARN', Level.WARNING) - info → const LogLevel
-
const LogLevel('INFO', Level.INFO) - unknown → const LogLevel
-
const LogLevel('unknown', Level.OFF)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- level → Level
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited