MonetizationPartContract class abstract interface

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

consumeEntitlement(Object applicationId, Object entitlementId) Future<void>
createTestEntitlement(Object applicationId, {required Object skuId, required Object ownerId, required EntitlementOwnerType ownerType}) Future<Entitlement>
deleteTestEntitlement(Object applicationId, Object entitlementId) Future<void>
fetchEntitlements(Object applicationId, {Object? userId, List<Object>? skuIds, Object? guildId, bool? excludeEnded, int? limit, Object? before, Object? after}) Future<List<Entitlement>>
fetchSkus(Object applicationId) Future<List<Sku>>
fetchSubscriptions(Object skuId, {Object? userId, int? limit, Object? before, Object? after}) Future<List<Subscription>>
getSubscription(Object skuId, Object subscriptionId) Future<Subscription>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited