- Implemented types
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create(
{required Object channelId, required String topic, StagePrivacyLevel? privacyLevel, bool? sendStartNotification, Object? guildScheduledEventId, String? reason}) → Future< StageInstance> -
delete(
{required Object channelId, String? reason}) → Future< void> -
get(
Object channelId) → Future< StageInstance> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
{required Object channelId, String? topic, StagePrivacyLevel? privacyLevel, String? reason}) → Future< StageInstance>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited