ThreadPartContract class abstract interface

Implemented types

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createFromMessage<T extends ThreadChannel>(Object? guildId, Object? channelId, Object? messageId, ThreadChannelBuilder builder, {String? reason}) → Future<T>
createWithoutMessage<T extends ThreadChannel>(Object? guildId, Object? channelId, ThreadChannelBuilder builder, {String? reason}) → Future<T>
fetchActives(Object guildId) → Future<ThreadResult>
fetchPrivateArchived(Object channelId) → Future<Map<Snowflake, PrivateThreadChannel>>
fetchPublicArchived(Object channelId) → Future<Map<Snowflake, PublicThreadChannel>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited