container library

Properties

ioc IocContainer
Returns the active IocContainer.
no setter

Functions

runWithIoc<T>(IocContainer container, Future<T> body()) Future<T>
Runs body inside a Zone where ioc resolves to container.
scopedIoc(IocContainer container) IocContainer Function()
Swaps the global container for container and returns a restore function.