OnboardingPromptOption class final
An option inside an OnboardingPrompt.
Constructors
Properties
-
channelIds
→ List<
Snowflake> -
Channel ids that a member gains access to when this option is selected.
final
- description → String?
-
The description of the option.
final
- emojiAnimated → bool?
-
Whether the emoji is animated.
final
- emojiId → Snowflake?
-
The emoji id if the emoji is custom.
final
- emojiName → String?
-
The emoji name if custom, the unicode character if standard, or null.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → Snowflake
-
The option's unique id.
final
-
roleIds
→ List<
Snowflake> -
Role ids assigned to the member when this option is selected.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
The title of the option.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited