CommandInteractionManager class final
- Implemented types
Constructors
- CommandInteractionManager({required DataStoreContract dataStore, required MarshallerContract marshaller, required EntityContext ctx})
-
factory
Properties
-
commands
→ List<
CommandBuilder> -
final
-
commandsHandler
→ List<
CommandRegistration> -
final
- dispatcher ↔ InteractionDispatcherContract
-
getter/setter pairoverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- onCommandError ↔ void Function(CommandFailure failure)?
-
getter/setter pairoverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addCommand(
CommandBuilder command) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerGlobal(
Bot bot) → Future< void> -
override
-
registerServer(
Bot bot, Server server) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited