CommandInteractionManagerContract class abstract

Implementers

Properties

commands List<CommandBuilder>
final
commandsHandler List<CommandRegistration>
final
dispatcher InteractionDispatcherContract
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
onCommandError ↔ void Function(CommandFailure failure)?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addCommand(CommandBuilder command) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerGlobal(Bot bot) Future<void>
registerServer(Bot bot, Server server) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited