forward<T extends Message> abstract method
Forward a message to another channel.
Posts a message_reference with type: 1 (FORWARD) to targetChannelId.
messageId is the id of the message being forwarded.
sourceChannelId is the channel the original message lives in.
guildId is optional; include it for guild messages.
Implementation
Future<T> forward<T extends Message>(
Snowflake targetChannelId, {
required Snowflake messageId,
required Snowflake sourceChannelId,
Snowflake? guildId,
});