Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create(Object guildId, {required String name, required String sound, double? volume, Object? emojiId, String? emojiName, String? reason})
→ Future<SoundboardSound>
-
-
delete(Object guildId, Object soundId, {String? reason})
→ Future<void>
-
-
fetchDefault()
→ Future<List<SoundboardSound>>
-
-
fetchForServer(Object guildId)
→ Future<Map<Snowflake, SoundboardSound>>
-
-
get(Object guildId, Object soundId)
→ Future<SoundboardSound>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
sendToChannel(Object channelId, {required Object soundId, Object? sourceGuildId})
→ Future<void>
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
update(Object guildId, Object soundId, {String? name, double? volume, Object? emojiId, String? emojiName, String? reason})
→ Future<SoundboardSound>
-