- Implemented types
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create(
Object guildId, {required String name, String? description}) → Future< GuildTemplate> -
delete(
Object guildId, String code) → Future< GuildTemplate> -
fetchForServer(
Object guildId) → Future< Map< String, GuildTemplate> > -
getByCode(
String code) → Future< GuildTemplate> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sync(
Object guildId, String code) → Future< GuildTemplate> -
toString(
) → String -
A string representation of this object.
inherited
-
update(
Object guildId, String code, {String? name, String? description}) → Future< GuildTemplate>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited