- Implemented types
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fetch(
Object guildId) → Future< WelcomeScreen> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
Object guildId, {bool? enabled, List< Map< ? welcomeChannels, String? description, String? reason}) → Future<String, dynamic> >WelcomeScreen>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited